==> commons-dbutils-1.1-src.tar.gz: commons-dbutils-1.1-src/src/test/org/apache/commons/dbutils/handlers/BeanListHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.dbutils.handlers;

import java.sql.SQLException;
import java.util.Iterator;
import java.util.List;

import org.apache.commons.dbutils.BaseTestCase;
import org.apache.commons.dbutils.ResultSetHandler;
import org.apache.commons.dbutils.TestBean;

/**
 * BeanListHandlerTest
 */
public class BeanListHandlerTest extends BaseTestCase {

	/**
	 * Constructor for BeanListHandlerTest.
	 */
	public BeanListHandlerTest(String name) {
		super(name);
	}

	public void testHandle() throws SQLException {
		ResultSetHandler h = new BeanListHandler(TestBean.class);
		List results = (List) h.handle(this.rs);

		assertNotNull(results);
		assertEquals(ROWS, results.size());

		Iterator iter = results.iterator();
		TestBean row = null;
		while (iter.hasNext()) {
			row = (TestBean) iter.next();
			assertNotNull(row);
		}

		assertEquals("4", row.getOne());
		assertEquals("5", row.getTwo());
		assertEquals("6", row.getThree());
		assertEquals("not set", row.getDoNotSet());
	}

	public void testEmptyResultSetHandle() throws SQLException {
		ResultSetHandler h = new BeanListHandler(TestBean.class);
		List results = (List) h.handle(this.emptyResultSet);

		assertNotNull(results);
		assertTrue(results.isEmpty());
	}

}

==> commons-dbutils-1.3-src.tar.gz: commons-dbutils-1.3-src/src/test/org/apache/commons/dbutils/handlers/BeanListHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.dbutils.handlers;

import java.sql.SQLException;
import java.util.Iterator;
import java.util.List;

import org.apache.commons.dbutils.BaseTestCase;
import org.apache.commons.dbutils.ResultSetHandler;
import org.apache.commons.dbutils.TestBean;

/**
 * BeanListHandlerTest
 */
public class BeanListHandlerTest extends BaseTestCase {

	public void testHandle() throws SQLException {
		ResultSetHandler<List<TestBean>> h = new BeanListHandler<TestBean>(TestBean.class);
		List<TestBean> results = (List<TestBean>) h.handle(this.rs);

		assertNotNull(results);
		assertEquals(ROWS, results.size());

		Iterator<TestBean> iter = results.iterator();
		TestBean row = null;
        assertTrue(iter.hasNext());
        row = (TestBean) iter.next();
        assertEquals("1", row.getOne());
        assertEquals("2", row.getTwo());
        assertEquals("3", row.getThree());
        assertEquals("not set", row.getDoNotSet());
            
        assertTrue(iter.hasNext());
        row = (TestBean) iter.next();

        assertEquals("4", row.getOne());
        assertEquals("5", row.getTwo());
        assertEquals("6", row.getThree());
        assertEquals("not set", row.getDoNotSet());
        
        assertFalse(iter.hasNext());
	}

	public void testEmptyResultSetHandle() throws SQLException {
		ResultSetHandler<List<TestBean>> h = new BeanListHandler<TestBean>(TestBean.class);
		List<TestBean> results = h.handle(this.emptyResultSet);

		assertNotNull(results);
		assertTrue(results.isEmpty());
	}

}
